/*
 *   Copyright (C) Christian Schulte, 2005-206
 *   All rights reserved.
 *
 *   Redistribution and use in source and binary forms, with or without
 *   modification, are permitted provided that the following conditions
 *   are met:
 *
 *     o Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *
 *     o Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 *
 *   THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 *   INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 *   AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 *   THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 *   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 *   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *   $JOMC: PropertiesResourceType.java 3838 2011-10-08 20:15:41Z schulte2005 $
 *
 */
package org.jomc.ant.types;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * Datatype describing a properties resource.
 *
 * @author <a href="mailto:schulte2005@users.sourceforge.net">Christian Schulte</a>
 * @version $JOMC: PropertiesResourceType.java 3838 2011-10-08 20:15:41Z schulte2005 $
 */
public class PropertiesResourceType extends ResourceType
{

    /** The format of the properties resource. */
    private PropertiesFormatType format;

    /** Creates a new {@code PropertiesResourceType} instance. */
    public PropertiesResourceType()
    {
        super();
    }

    /**
     * Gets the value of the {@code format} property.
     *
     * @return The value of the {@code format} property.
     *
     * @see #setFormat(org.jomc.ant.types.PropertiesFormatType)
     */
    public final PropertiesFormatType getFormat()
    {
        if ( this.format == null )
        {
            this.format = PropertiesFormatType.PLAIN;
        }

        return this.format;
    }

    /**
     * Sets the value of the {@code format} property.
     *
     * @param value The new value of the {@code format} property or {@code null}.
     *
     * @see #getFormat()
     */
    public final void setFormat( final PropertiesFormatType value )
    {
        this.format = value;
    }

    /**
     * Creates and returns a copy of this object.
     *
     * @return A copy of this object.
     */
    @Override
    public PropertiesResourceType clone()
    {
        return (PropertiesResourceType) super.clone();
    }

    /**
     * Creates and returns a string representation of the object.
     *
     * @return A string representation of the object.
     */
    @Override
    public String toString()
    {
        return ToStringBuilder.reflectionToString( this );
    }

}
